Documentation
¶
Index ¶
- func Alignof[ArbitraryType _ArbitraryType](x ArbitraryType) uintptr
- func F[F interface{ ... }](f F, typ ...Type) field
- func Field[F interface{ ... }](f F, typ ...Type) field
- func Sizeof[ArbitraryType _ArbitraryType](x ArbitraryType) uintptr
- func Slice[ArbitraryType _ArbitraryType, IntegerType _IntegerType](ptr *ArbitraryType, len IntegerType) []ArbitraryType
- func SliceData[ArbitraryType _ArbitraryType](slice []ArbitraryType) *ArbitraryType
- func String[IntegerType _IntegerType](ptr *byte, len IntegerType) string
- func StringData(str string) *byte
- func Value[T any](strct any, f field) T
- type Pointer
- type Type
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Field ¶
Field selects a field in a struct. The field can be selected by passing an integer or a (name) string. An optional type constraint can be provided as a safety precaution to ensure that the field's type is what you expected.
func Slice ¶
func Slice[ArbitraryType _ArbitraryType, IntegerType _IntegerType](ptr *ArbitraryType, len IntegerType) []ArbitraryType
Slice
func SliceData ¶
func SliceData[ArbitraryType _ArbitraryType](slice []ArbitraryType) *ArbitraryType
SliceData
func StringData ¶
StringData
Types ¶
type Pointer ¶
Pointer
Click to show internal directories.
Click to hide internal directories.