Documentation
¶
Index ¶
- func Alignof[_ArbitraryType ArbitraryType](x _ArbitraryType) uintptr
- func F[F interface{ ... }](f F, typ ...reflect.Type) field
- func Field[F interface{ ... }](f F, typ ...reflect.Type) field
- func Sizeof[_ArbitraryType ArbitraryType](x _ArbitraryType) uintptr
- func Slice[_ArbitraryType ArbitraryType, _IntegerType IntegerType](ptr *_ArbitraryType, len _IntegerType) []_ArbitraryType
- func SliceData[_ArbitraryType ArbitraryType](slice []_ArbitraryType) *_ArbitraryType
- func String[_IntegerType IntegerType](ptr *byte, len _IntegerType) string
- func StringData(str string) *byte
- func Value[V any](strct any, f field) V
- type ArbitraryType
- type IntegerType
- type Pointer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Alignof ¶
func Alignof[_ArbitraryType ArbitraryType](x _ArbitraryType) uintptr
func Field ¶
Field selects which field in a struct you wish to modify. The field name can be selected by passing an integer or a string. An optional type constraint can be provided as a safety precaution to ensure that the field's type is what you expected.
func Sizeof ¶
func Sizeof[_ArbitraryType ArbitraryType](x _ArbitraryType) uintptr
func Slice ¶
func Slice[_ArbitraryType ArbitraryType, _IntegerType IntegerType](ptr *_ArbitraryType, len _IntegerType) []_ArbitraryType
func SliceData ¶
func SliceData[_ArbitraryType ArbitraryType](slice []_ArbitraryType) *_ArbitraryType
func String ¶
func String[_IntegerType IntegerType](ptr *byte, len _IntegerType) string
func StringData ¶
Types ¶
type ArbitraryType ¶
type ArbitraryType interface {
any
}
type IntegerType ¶
type Pointer ¶
func Add ¶
func Add[_IntegerType IntegerType](ptr Pointer, len _IntegerType) Pointer
Click to show internal directories.
Click to hide internal directories.